from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="MqttAclRequest")


@_attrs_define
class MqttAclRequest:
    """MQTT ACL check request (mosquitto-go-auth format).

    mosquitto ACL checks use a bitmask:
    - MOSQ_ACL_READ      0x01
    - MOSQ_ACL_WRITE     0x02
    - MOSQ_ACL_SUBSCRIBE 0x04

        Attributes:
            acc (int): Access mask (READ|WRITE|SUBSCRIBE)
            topic (str): MQTT topic
            clientid (str | Unset): MQTT client ID Default: ''.
    """

    acc: int
    topic: str
    clientid: str | Unset = ""
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        acc = self.acc

        topic = self.topic

        clientid = self.clientid

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "acc": acc,
                "topic": topic,
            }
        )
        if clientid is not UNSET:
            field_dict["clientid"] = clientid

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        acc = d.pop("acc")

        topic = d.pop("topic")

        clientid = d.pop("clientid", UNSET)

        mqtt_acl_request = cls(
            acc=acc,
            topic=topic,
            clientid=clientid,
        )

        mqtt_acl_request.additional_properties = d
        return mqtt_acl_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
